Module git

Module git 

Structs

ReadCommitMessageOptions
ReadCommitMessageOptions represents the options for reading commit messages. Transparently, it is defined to be similar to the behavior of the git log command.

Functions

edit_msg_path
Get the path to the COMMIT_EDITMSG file.
parse_commit_message
Parse a commit message and return the subject, body, and footers.
parse_subject
Parse a commit message subject and return the type, scope, and description.
read
Get commit messages from git.